==> connect-markdown-renderer-1.0.0.tar.gz: connect-markdown-renderer-1.0.0/cmr/theme.py <==
DEFAULT_THEME = {
    'headings': {
        1: {
            'fg': 'darkslateblue',
        },
        2: {
            'fg': 'slateblue',
        },
        3: {
            'fg': 'mediumslateblue',
        },
        4: {
            'fg': 'deepskyblue',
        },
        5: {
            'fg': 'skyblue',
        },
        6: {
            'fg': 'lightskyblue',
        },
    },
    'p': {
        'fg': 'white',
    },
    'strong': {
        'fg': 'indigo',
        'style': 'bold',
    },
    'em': {
        'fg': 'mediumorchid',
        'style': 'bold',
    },
    'del': {
        'fg': 'olive',
        'style': 'bold',
    },
    'hr': {
        'delimiter': '◈',
        'line': '─',
        'color': {
            'fg': 'hotpink',
        }
    },
    'img': {
        'start_symbol': '\U0001F5bc',
        'end_symbol': '\U0001F5bc',
        'text_color': {
            'fg': 'orange',
        },
        'link_color': {
            'fg': 'white',
            'style': 'bold+underline',
        },
    },
    'ol': {
        'separator': '. ',
        'color': {
            'fg': 'yellow',
        }
    },
    'ul': {
        'symbol': '•',
        'separator': ' ',
        'color': {
            'fg': 'magenta',
        },
    },
    'blockquote': {
        'symbol': '┃',
        'separator': ' ',
        'indent': '  ',
        'color': {
            'fg': 'gray',
        },
    },
    'a': {
        'start_symbol': '↣',
        'end_symbol': '↤',
        'text_color': {
            'fg': 'gray',
        },
        'link_color': {
            'fg': 'white',
            'style': 'bold+underline',
        },
    },
    'code': {
        'fg': 'red',
        'bg': 'lightgray',
        'style': 'bold',
    },
    'table': {
        'horizontal_char': '─',
        'vertical_char': '│',
        'intersection_char': '┼',
        'top_left_char': '┌',
        'top_right_char': '┐',
        'bottom_left_char': '└',
        'bottom_right_char': '┘',
        'left_junction_char': '├',
        'right_junction_char': '┤',
        'top_junction_char': '┬',
        'bottom_junction_char': '┴',
        'line_color': {
            'fg': 'yellow',
        },
        'header_color': {
            'fg': 'brown',
        },
        'cell_color': {
            'fg': 'purple',
        }
    }
}

==> connect-markdown-renderer-1.0.1.tar.gz: connect-markdown-renderer-1.0.1/cmr/theme.py <==
DEFAULT_THEME = {
    'headings': {
        1: {
            'fg': 'aquamarine',
        },
        2: {
            'fg': 'turquoise',
        },
        3: {
            'fg': 'mediumturquoise',
        },
        4: {
            'fg': 'darkturquoise',
        },
        5: {
            'fg': 'lightseagreen',
        },
        6: {
            'fg': 'teal',
        },
    },
    'p': {
        'fg': 'white',
    },
    'strong': {
        'fg': 'mediumpurple',
        'style': 'bold',
    },
    'em': {
        'fg': 'plum',
        'style': 'bold',
    },
    'del': {
        'fg': 'darkorchid',
    },
    'hr': {
        'delimiter': '◈',
        'line': '─',
        'color': {
            'fg': 'aqua',
        }
    },
    'img': {
        'start_symbol': '\U0001f3a8',
        'end_symbol': '\U0001f3a8',
        'text_color': {
            'fg': 'white',
        },
        'link_color': {
            'fg': 'hotpink',
            'style': 'bold',
        },
    },
    'ol': {
        'separator': '. ',
        'color': {
            'fg': 'royalblue',
        }
    },
    'ul': {
        'symbol': '•',
        'separator': ' ',
        'color': {
            'fg': 'dodgerblue',
        },
    },
    'blockquote': {
        'symbol': '┃',
        'separator': ' ',
        'indent': '  ',
        'color': {
            'fg': 'lavender',
        },
    },
    'a': {
        'start_symbol': '\U0001F517',
        'end_symbol': '\U0001F517',
        'text_color': {
            'fg': 'white',
        },
        'link_color': {
            'fg': 'hotpink',
            'style': 'bold',
        },
    },
    'code': {
        'fg': 'red',
        'bg': 'lightgray',
        'style': 'bold',
    },
    'table': {
        'horizontal_char': '─',
        'vertical_char': '│',
        'intersection_char': '┼',
        'top_left_char': '┌',
        'top_right_char': '┐',
        'bottom_left_char': '└',
        'bottom_right_char': '┘',
        'left_junction_char': '├',
        'right_junction_char': '┤',
        'top_junction_char': '┬',
        'bottom_junction_char': '┴',
        'line_color': {
            'fg': 'cornflowerblue',
        },
        'header_color': {
            'fg': 'lightskyblue',
            'style': 'bold',

        },
        'cell_color': {
            'fg': 'lightcyan',
        }
    }
}
